<?php
add_filter('the_excerpt', function($excerpt){
	$post	= get_post();
	$format	= get_post_format($post);

	if($format){
		$post_content	= maybe_unserialize($post->post_content);
		if($post_content && is_array($post_content)){
			if($format == 'gallery' || $format == 'video'){
				$excerpt	= $post_content['text'] ?? '';
			}elseif($format == 'image'){
				$excerpt	= $post_content[0]['text'] ?? '';
			}

			$excerpt = wp_strip_all_tags($excerpt);	
		
			return trim( preg_replace( "/[\n\r\t ]+/", ' ', $excerpt ), ' ' );
		}
	}

	return get_post_excerpt($post, 350);
});

add_filter('the_content', function($content){
	$post	= get_post();
	$format	= get_post_format($post);

	if(empty($format)){
		return $content;
	}
	
	$post_content	= maybe_unserialize($post->post_content);

	if(empty($post_content) || !is_array($post_content)){
		return $content;
	}

	if($format == 'gallery'){
		$images	= $post_content['images'] ?? [];
		$text	= $post_content['text'] ?? '';

		$gallery	= '';

		if($images){
			$count	= count($images);

			if($count == 1){
				$gallery	= '<img src="'.wpjam_get_thumbnail($images[0], 1200).'" alt="'.$post->post_title.'">';
			}else{
				$per 	= ($count == 4) ? 2 : 3;
				$i		= 0;
				foreach ($images as $image) {
					$i ++;

					if($count == 2 || $count == 4){
						$style	= ' style="float:left; margin: 0 0 4% 0;  width:48%; paddding: 0;"';

						if($i%$per != 0){
							$style	= ' style="float:left; margin:0 4% 4% 0;  width:48%; paddding: 0;"';
						}

						$width	= 400;
					}else{
						$style	= ' style="float:left; margin: 0 0 2% 0;  width:32%; paddding: 0;"';

						if($i%$per != 0){
							$style	= ' style="float:left; margin:0 2% 2% 0;  width:32%; paddding: 0;"';
						}

						$width	= 300;
					}

					$gallery	.= '
					<dl class="gallery-item"'.$style.'>
						<dt class="gallery-icon">
							<a data-fancybox="gallery" href="'.wpjam_get_thumbnail($image, 1200).'"><img src="'.wpjam_get_thumbnail($image, [$width,$width]).'" alt="'.$post->post_title.'"></a>
						</dt>
					</dl>
					';

					if($i%$per == 0 && $i != $count){
						$gallery .= '<dl style="clear: both; margin:0; padding:0;"></dl>';
					}
				}

				$gallery .= '<dl style="clear: both; margin:0; padding:0;"></dl>';
				$gallery = '<div class="gallery" >'.$gallery.'</div>';	
			}
		}

		return $gallery.wpautop($text);
	}elseif($format == 'video'){
		$video	= $post_content['video'] ?? '';
		$image	= $post_content['image'] ?? '';
		$text	= $post_content['text'] ?? '';

		if($video){
			if(wp_is_mobile()){
				$width	= '100%';
				$height	= 200;
			}else{
				$width	= 640;
				$height	= 400;
			}

			if(filter_var($video, FILTER_VALIDATE_URL)){ 
				$video	= '<video controls width="'.$width.'" height="'.$height.'"  poster="'.$image.'" src="'.$video.'"></video>'."\n\n";
			}else{
				$video	= '<iframe frameborder="0" width="'.$width.'" height="'.$height.'" src="https://v.qq.com/txp/iframe/player.html?vid='.$video.'" allowFullScreen="true"></iframe>'."\n\n";
			}
		}

		return wpautop($video.$text);
	}elseif($format == 'image'){
		$content	= '';
		foreach ($post_content as $item) {
			$image		= $item['image'] ?? '';
			if(!empty($item['image'])){
				$content	.= '<img src="'.wpjam_get_thumbnail($image, 1200).'" alt="'.$item['text'].'" />'."\n";
			}

			if(!empty($item['text'])){
				$content	.= $item['text']."\n";
			}

			$content	.= "\n";
		}

		return wpautop($content);
	}
});

add_filter('wpjam_post_thumbnail_url', function($thumbnail_url, $post){
	$format	= get_post_format($post);

	if(empty($format)){
		return $thumbnail_url;
	}
	
	$post_content	= maybe_unserialize($post->post_content);
	if($post_content && is_array($post_content)){
		if($format == 'gallery'){
			$images	= $post_content['images'] ?? [];
			if($images){
				return $images[0];
			}
		}elseif($format == 'image'){
			if($post_content[0]['image']){
				return $post_content[0]['image'];
			}
		}elseif($format == 'video'){
			if($post_content['image']){
				return $post_content['image'];
			}
		}
	}

	return $thumbnail_url;
}, 10, 2);

add_filter('wpjam_post_json', function($post_json, $post_id){
	$post_json['editable']	= false;

	$format = $post_json['format'] ?? '';
	
	if(empty($format)){
		return $post_json;
	}
	
	$post_content	= maybe_unserialize(WPJAM_Post::get_content($post_id, $raw=true));

	if(empty($post_content) || !is_array($post_content)){
		return $post_json;
	}

	$wpjam_user	= wpjam_get_current_user();
	if(empty($wpjam_user) || is_wp_error($wpjam_user) || empty($wpjam_user['user_id'])){
		$post_json['editable']	= false;
	}else{
		if($post_json['author']['id'] == $wpjam_user['user_id']){
			if($post_json['status'] == 'publish' && user_can(!$wpjam_user['user_id'], 'edit_published_posts')){
				$post_json['editable']	= false;
			}elseif(user_can($wpjam_user['user_id'], 'edit_posts')){
				$post_json['editable']	= true;
			}
		}
	}

	if($format == 'gallery'){
		$images	= $post_content['images'] ?? [];
		$text	= $post_content['text'] ?? '';

		$gallery	= [];

		if($images){
			$count	= count($images);

			if($count == 1){
				$width	= 1200;
				$height	= 0;
			}elseif($count == 2 || $count == 4){
				$width	= $height = 400;
			}else{
				$width	= $height = 300;
			}

			$gallery	= array_map(function($image) use($width, $height){
				return [
					'thumbnail'	=> wpjam_get_thumbnail($image,  [$width, $height]), 
					'image'		=> wpjam_get_thumbnail($image, 1200),
					'raw'		=> wpjam_get_thumbnail($image)
				];
			}, $images);
		}

		$post_json['format_content']	= compact('gallery', 'text');

	}elseif($format == 'video'){
		$text	= $post_content['text'] ?? '';
		$video	= $post_content['video'] ?? '';
		$raw	= $post_content['image'] ?? '';
		$poster	= $raw ? wpjam_get_thumbnail($raw, '640x400') : '';

		$post_json['format_content']	= compact('video', 'poster', 'raw', 'text');

		$post_json['editable']	= false;
	}elseif($format == 'image'){
		$images	= [];
		foreach($post_content as $item) {
			$image = $item['image'] ?? '';
			$images[]	=[
				'image'	=> $image ? wpjam_get_thumbnail($image, 1200) : '', 
				'raw'	=> $image,
				'text'	=> $item['text']
			];
		}

		$post_json['format_content']	= compact('images'); 
	}else{
		$post_json['editable']	= false;
	}

	return $post_json;
}, 10, 2);




